@@ -3,7 +3,7 @@ from typing import Optional, Union, List
 from urllib.parse import urlencode
 
 from .base import BaseClient
-from .const import HTTPMethods
+from .const import HTTPMethods, Currencies
 from .models.balance import Balance
 from .models.transaction import Transaction
 
@@ -87,8 +87,8 @@ class Payok(BaseClient):
         self,
         amount: float,
         payment: Union[int, str],
-        currency: Optional[str] = 'RUB',
-        desc: Optional[str] = None,
+        currency: Optional[str] = Currencies.RUB,
+        desc: Optional[str] = 'Description',
         email: Optional[str] = None,
         success_url: Optional[str] = None,
         method: Optional[str] = None,
@@ -124,6 +124,10 @@ class Payok(BaseClient):
             'custom': custom
         }
 
+        for key, value in params.copy().items():
+            if value is None:
+                del params[key]
+
         sign_params = '|'.join(map(
             str,
             [amount, payment, self._shop, currency, desc, self.__secret_key]
