@@ -1,6 +1,6 @@
-from pydantic import BaseModel
+from typing import Union
 
-from typing import List
+from pydantic import BaseModel
 
 
 class Transaction(BaseModel):
@@ -15,7 +15,7 @@ class Transaction(BaseModel):
     comission_fixed: float
     amount_profit: float
     method: str
-    payment_id: int
+    payment_id: Union[int, str]
     description: str
     date: str
     pay_date: str
@@ -23,8 +23,3 @@ class Transaction(BaseModel):
     custom_fields: str
     webhook_status: int
     webhook_amount: int
-
-class Transactions(BaseModel):
-    '''Payok API transactions model'''
-
-    transactions: List[Transaction]
\ No newline at end of file
